"""
Author: Michel Peltriaux
Organization: Struktur- und Genehmigungsdirektion Nord, Rhineland-Palatinate, Germany
Contact: michel.peltriaux@sgdnord.rlp.de
Created on: 30.11.20

"""
from django.urls import path

from intervention.views import index_view, new_view, detail_view, edit_view, remove_view, new_document_view, share_view, \
    create_share_view, remove_revocation_view, new_revocation_view, check_view, log_view, new_deduction_view, \
    record_view, remove_document_view, get_document_view, get_revocation_view, new_id_view, report_view, \
    remove_deduction_view, remove_compensation_view, edit_deduction_view, edit_revocation_view, edit_document_view

app_name = "intervention"
urlpatterns = [
    path("", index_view, name="index"),
    path('new/', new_view, name='new'),
    path('new/id', new_id_view, name='new-id'),
    path('<id>', detail_view, name='detail'),
    path('<id>/log', log_view, name='log'),
    path('<id>/edit', edit_view, name='edit'),
    path('<id>/remove', remove_view, name='remove'),
    path('<id>/share/<token>', share_view, name='share'),
    path('<id>/share', create_share_view, name='share-create'),
    path('<id>/check', check_view, name='check'),
    path('<id>/record', record_view, name='record'),
    path('<id>/report', report_view, name='report'),

    # Compensations
    path('<id>/compensation/<comp_id>/remove', remove_compensation_view, name='remove-compensation'),

    # Documents
    path('<id>/document/new/', new_document_view, name='new-doc'),
    path('<id>/document/<doc_id>', get_document_view, name='get-doc'),
    path('<id>/document/<doc_id>/remove/', remove_document_view, name='remove-doc'),
    path('<id>/document/<doc_id>/edit/', edit_document_view, name='edit-doc'),

    # Deductions
    path('<id>/deduction/new', new_deduction_view, name='new-deduction'),
    path('<id>/deduction/<deduction_id>/edit', edit_deduction_view, name='edit-deduction'),
    path('<id>/deduction/<deduction_id>/remove', remove_deduction_view, name='remove-deduction'),

    # Revocation routes
    path('<id>/revocation/new', new_revocation_view, name='new-revocation'),
    path('<id>/revocation/<revocation_id>/edit', edit_revocation_view, name='edit-revocation'),
    path('<id>/revocation/<revocation_id>/remove', remove_revocation_view, name='remove-revocation'),
    path('revocation/<doc_id>', get_revocation_view, name='get-doc-revocation'),
]